@@ -27,7 +27,6 @@
 #define HAVE_BSEARCH 1
 #define HAVE_CRYPT_H 1
 #define HAVE_CURSES_H 1
-#define HAVE_CXXABI_H 1
 /* #undef HAVE_BFD_H */
 /* #undef HAVE_NCURSES_H */
 /* #undef HAVE_NDIR_H */
@@ -94,6 +93,7 @@
 #define HAVE_SYS_TYPES_H 1
 #define HAVE_SYS_UN_H 1
 /* #undef HAVE_SYS_VADVISE_H */
+#define HAVE_UCONTEXT_H 1
 #define HAVE_TERM_H 1
 /* #undef HAVE_TERMBITS_H */
 #define HAVE_TERMIOS_H 1
@@ -290,7 +290,6 @@
 /* #undef HAVE_THR_YIELD */
 #define HAVE_TIME 1
 #define HAVE_TIMES 1
-/* #undef HAVE_UCONTEXT */
 #define HAVE_VALLOC 1
 #define HAVE_VIDATTR 1
 #define HAVE_VIO_READ_BUFF 1
@@ -318,6 +317,8 @@
 /* #undef HAVE_TIMESPEC_TS_SEC */
 #define STRUCT_DIRENT_HAS_D_INO 1
 /* #undef STRUCT_DIRENT_HAS_D_NAMLEN */
+#define STRUCT_TIMESPEC_HAS_TV_SEC 1
+#define STRUCT_TIMESPEC_HAS_TV_NSEC 1
 #define SPRINTF_RETURNS_INT 1
 
 #define USE_MB 1
@@ -395,7 +396,7 @@
 
 #define SOCKET_SIZE_TYPE socklen_t
 
-#define HAVE_MBSTATE_T
+#define HAVE_MBSTATE_T 1
 
 #define MAX_INDEXES 64
 
@@ -405,6 +406,7 @@
 #define SIGNAL_RETURN_TYPE_IS_VOID 1
 #define RETSIGTYPE void
 #define VOID_SIGHANDLER 1
+#define HAVE_SIGHANDLER_T 1
 #define STRUCT_RLIMIT struct rlimit
 
 #ifdef __APPLE__
@@ -430,15 +432,15 @@
 #define HAVE_WCTYPE_H 1
 #define HAVE_WCHAR_H 1
 #define HAVE_LANGINFO_H 1
-#define HAVE_MBRLEN
+#define HAVE_MBRLEN 1
 /* #undef HAVE_MBSCMP */
-#define HAVE_MBSRTOWCS
-#define HAVE_WCRTOMB
-#define HAVE_MBRTOWC
-#define HAVE_WCSCOLL
-#define HAVE_WCSDUP
-#define HAVE_WCWIDTH
-#define HAVE_WCTYPE
+#define HAVE_MBSRTOWCS 1
+#define HAVE_WCRTOMB 1
+#define HAVE_MBRTOWC 1
+#define HAVE_WCSCOLL 1
+#define HAVE_WCSDUP 1
+#define HAVE_WCWIDTH 1
+#define HAVE_WCTYPE 1
 #define HAVE_ISWLOWER 1
 #define HAVE_ISWUPPER 1
 #define HAVE_TOWLOWER 1
@@ -452,7 +454,7 @@
 #define HAVE_STRCASECMP 1
 #define HAVE_STRNCASECMP 1
 #define HAVE_STRDUP 1
-#define HAVE_LANGINFO_CODESET 
+#define HAVE_LANGINFO_CODESET  1
 #define HAVE_TCGETATTR 1
 #define HAVE_FLOCKFILE 1
 
@@ -464,13 +466,14 @@
 /* #undef HAVE_BSD_SIGNALS */
 /* #undef HAVE_SVR3_SIGNALS */
 /* #undef HAVE_V7_SIGNALS */
-
+/* #undef HAVE_ERR_remove_thread_state */
 
 /* #undef HAVE_SOLARIS_STYLE_GETHOST */
 
 /* #undef MY_ATOMIC_MODE_DUMMY */
 /* #undef MY_ATOMIC_MODE_RWLOCKS */
 #define HAVE_GCC_ATOMIC_BUILTINS 1
+#define HAVE_GCC_C11_ATOMICS 1
 /* #undef HAVE_SOLARIS_ATOMIC */
 #define HAVE_DECL_SHM_HUGETLB 1
 #define HAVE_LARGE_PAGES 1
@@ -489,6 +492,7 @@
 
 #define SYSTEM_TYPE "Linux"
 #define MACHINE_TYPE "x86_64"
+#define DEFAULT_MACHINE "x86_64"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -514,6 +518,10 @@
 /* #undef strtoll */
 /* #undef strtoull */
 /* #undef vsnprintf */
+#if (_MSC_VER > 1800)
+#define tzname _tzname
+#define P_tmpdir "C:\\TEMP"
+#endif
 #if (_MSC_VER > 1310)
 # define HAVE_SETENV
 #define setenv(a,b,c) _putenv_s(a,b)
@@ -522,7 +530,7 @@
 
 /* We don't want the min/max macros */
 #ifdef __WIN__
-#define NOMINMAX
+#define NOMINMAX 1
 #endif
 
 /*
@@ -629,16 +637,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 0
-#define MYSQL_VERSION_PATCH 16
+#define MYSQL_VERSION_PATCH 24
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.0.16"
+#define PACKAGE_STRING "MySQL Server 10.0.24"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.0.16"
-#define VERSION "10.0.16"
+#define PACKAGE_VERSION "10.0.24"
+#define VERSION "10.0.24"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "bundled jemalloc"
